"""Integration point with all sub-packages."""
import click
from mbed_devices.mbed_tools.cli import cli as mbed_devices_cli


CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])


@click.group(context_settings=CONTEXT_SETTINGS)
def cli() -> None:
    """Main entry point for the cli."""
    pass


cli.add_command(mbed_devices_cli, "devices")



"""The version number is based on semantic versioning.

References
- https://semver.org/
- https://www.python.org/dev/peps/pep-0440/

This file is autogenerated, do not modify by hand.
"""
__version__ = "1.0.0-beta.6"
COMMIT = "88d4dfe9dc06665d05a13b6771c3f85512541ef3"
MAJOR = 1
MINOR = 0
PATCH = 0
